Virtual uinput device for forwarding and emitting key events. uinput virtual device for event forwarding and emission.
In grab mode, unmatched key events are re-emitted through a virtual device so they reach applications normally.
Note: keyd creates two virtual devices (keyboard + pointer). For now we only need one (keyboard).
Modules
- testing
testing - Test utilities for the forwarder — recording forwarder for assertions.
Structs
- Uinput
Forwarder - Virtual uinput device for forwarding unmatched key events in grab mode.
Traits
- Forward
Sink - Sink for forwarding key events through a virtual device.