Device discovery, hotplug monitoring, and event polling. Device discovery, hotplug, and capability detection.
Manages the set of active input devices. Uses inotify to watch
/dev/input/ for device add/remove events. Probes new devices for
keyboard capabilities before adding them to the poll set.
Structs
- Device
KeyEvent - A key event from a specific device.
- Device
Manager - Manages discovered input devices and watches for hotplug events.
- Poll
Result - Result of processing polled events.
Enums
- Device
Grab Mode - Whether devices should be grabbed for exclusive access.
Constants
- INPUT_
DIRECTORY - Default path to the Linux input device directory.