uinput virtual device for event forwarding.
In grab mode, unmatched key events are re-emitted through a virtual device so they reach applications normally.
Synthetic action emission is planned but is not implemented yet. Unlike tools such as keyd, this crate currently needs only a keyboard virtual device.
Modules
- testing
testing - Test utilities for the forwarder — recording forwarder for assertions.
Structs
- Uinput
Forwarder - Virtual uinput device for forwarding unmatched key events in grab mode.
Traits
- Forward
Sink - Sink for forwarding key events through a virtual device.